import React from 'react';
import {
	SmileOutlined,
	CrownOutlined,
	SettingOutlined,
	FundOutlined,
	BankOutlined,
	BranchesOutlined,
	CheckCircleOutlined,
	UsergroupAddOutlined,
	HeatMapOutlined,
} from '@ant-design/icons';
import adminLayout from '../layout/adminLayout';
import blankLayout from '../layout/blankLayout';
import login from '../page/login';
import welcome from '../page/welcome';
import { ChangePile, ChangeStation } from '../page/device';
import { dailyInspection, malfunction, workorder } from '../page/inspection';
import staff from '../page/staff';
import area from '../page/area';
import dataAnalysis from '../page/dataAnalysis';
import { User, character } from '../page/setting';
import NotFound from '../page/404';

export const routeConfig: routeItemProps[] = [
	{
		path: '/login',
		name: '登录',
		component: login,
	},
	{
		path: '/',
		component: adminLayout,
		exact: false,
		authority: 'admin',
		routes: [
			{
				path: '/welcome',
				icon: <SmileOutlined />,
				name: '首页',
				component: welcome,
			},
			{
				path: '/device/station',
				icon: <BankOutlined />,
				name: '充电站管理',
				component: ChangeStation,
			},
			{
				path: '/device/pile',
				icon: <BranchesOutlined />,
				name: '充电桩管理',
				component: ChangePile,
			},
			{
				path: '/inspection',
				icon: <CheckCircleOutlined />,
				name: '巡检管理',
				component: blankLayout,
				routes: [
					{
						path: '/inspection/dailyInspection',
						name: '日常巡检',
						icon: <CrownOutlined />,
						component: dailyInspection,
					},
					{
						path: '/inspection/malfunction',
						name: '故障保修',
						icon: <SmileOutlined />,
						component: malfunction,
					},
					{
						path: '/inspection/workorder',
						name: '工单任务',
						icon: <SmileOutlined />,
						component: workorder,
					},
				],
			},
			{
				path: '/staff',
				name: '人员管理',
				icon: <UsergroupAddOutlined />,
				component: staff,
			},
			{
				path: '/area',
				name: '区域管理',
				icon: <HeatMapOutlined />,
				component: area,
			},
			{
				path: '/dataAnalysis',
				name: '数据分析',
				icon: <FundOutlined />,
				component: dataAnalysis,
			},
			{
				path: '/setting',
				name: '系统管理',
				icon: <SettingOutlined />,
				component: blankLayout,
				routes: [
					{
						path: '/setting/user',
						name: '用户管理',
						icon: <CrownOutlined />,
						component: User,
					},
					{
						path: '/setting/character',
						name: '角色管理',
						icon: <SmileOutlined />,
						component: character,
					},
					{
						path: '/setting',
						exact: true,
						redirect: '/setting/user',
					},
				],
			},
			{
				path: '/',
				exact: true,
				hideInMenu: true,
				redirect: '/welcome',
			},
			{
				path: '*',
				name: '404',
				hideInMenu: true,
				component: NotFound,
			},
		],
	},
];
export type routeItemProps = {
	path: string;
	name?: string;
	icon?: JSX.Element;
	component?: any;
	exact?: boolean;
	redirect?: string;
	authority?: string;
	routes?: routeItemProps[];
	hideInMenu?: boolean;
};
