import React, { useState } from 'react';
import { withRouter } from 'react-router-dom';
import { Avatar, Menu, Dropdown } from 'antd';
import ProLayout, {
	PageContainer,
	SettingDrawer,
	DefaultFooter,
} from '@ant-design/pro-layout';
import { GithubOutlined, UserOutlined } from '@ant-design/icons';
import { layoutDefaultConfig } from '../config/layout';
import { routeItemProps } from '../config/routes';
import { RouteComponentProps } from 'react-router-dom';
const defaultFooterDom = (
	<DefaultFooter
		copyright={`${new Date().getFullYear()} 蚂蚁集团体验技术部出品`}
		links={[
			{
				key: 'Ant Design Pro',
				title: 'Ant Design Pro',
				href: 'https://pro.ant.design',
				blankTarget: true,
			},
			{
				key: 'github',
				title: <GithubOutlined />,
				href: 'https://github.com/ant-design/ant-design-pro',
				blankTarget: true,
			},
			{
				key: 'Ant Design',
				title: 'Ant Design',
				href: 'https://ant.design',
				blankTarget: true,
			},
		]}
	/>
);

const adminLayout: React.FC<
	RouteComponentProps & { routes: routeItemProps[] }
> = ({ location, history, routes = [], children }) => {
	const [layoutConfigState, changeLayoutSeting] = useState(layoutDefaultConfig);
	const menu = (
		<Menu>
			<Menu.Item>个人中心</Menu.Item>
			<Menu.Item
				onClick={() => {
					window.localStorage.clear();
					history.push('/login');
				}}>
				退出登录
			</Menu.Item>
		</Menu>
	);
	return (
		<div
			id='test-pro-layout'
			style={{
				height: '100vh',
			}}>
			<ProLayout
				{...layoutConfigState}
				route={{
					path: '/',
					routes: routes,
				}}
				onMenuHeaderClick={() => history.push('/')}
				location={{
					pathname: location.pathname,
				}}
				menuItemRender={(item, dom) => (
					<a
						onClick={() => {
							history.push(item.path || '/');
						}}>
						{dom}
					</a>
				)}
				footerRender={() => {
					return defaultFooterDom;
				}}
				rightContentRender={() => (
					<Dropdown overlay={menu} placement='bottomRight'>
						<a
							className='ant-dropdown-link'
							onClick={(e) => e.preventDefault()}>
							<Avatar shape='square' size='small' icon={<UserOutlined />} />
						</a>
					</Dropdown>
				)}>
				<PageContainer>{children}</PageContainer>
			</ProLayout>
			{/* {process.env.NODE_ENV === 'development' ? (
				<SettingDrawer
					settings={layoutConfigState}
					onSettingChange={changeLayoutSeting}></SettingDrawer>
			) : null} */}
			<SettingDrawer
				settings={layoutConfigState}
				onSettingChange={changeLayoutSeting}></SettingDrawer>
		</div>
	);
};
export default withRouter(adminLayout);
