import React from 'react';
import { message } from 'antd';
import { RouteComponentProps } from 'react-router-dom';
import ProForm, { ProFormText } from '@ant-design/pro-form';
import { useRequest } from 'ahooks';
import { sha256 } from 'js-sha256';
import { MobileOutlined, LockOutlined, KeyOutlined } from '@ant-design/icons';
import './style.scss';
import { useAuth } from '../../router/index';
const Login: React.FC<RouteComponentProps> = ({ history }) => {
	const auth = useAuth();
	const { loading, run } = useRequest(
		(data) => ({
			method: 'POST',
			url: '/v1/user/login',
			data: {
				...data,
				password: sha256(data.password),
			},
		}),
		{
			manual: true,
			onSuccess: (response) => {
				sessionStorage.setItem('userinfo', JSON.stringify(response));
				sessionStorage.setItem('token', response.token);
				auth?.signin(response, () => {
					message.success('登录成功', 1, () => {
						history.replace('/');
					});
				});
			},
			onError: (error) => {
				message.error(error.message);
			},
		}
	);
	return (
		<div className='login_layout'>
			<ProForm
				className='login_card'
				onFinish={run}
				submitter={{
					searchConfig: {
						submitText: '登录',
					},
					render: (_, dom) => dom.pop(),
					submitButtonProps: {
						size: 'large',
						loading,
						style: {
							width: '100%',
						},
					},
				}}>
				<h1
					style={{
						textAlign: 'center',
					}}>
					<img
						style={{
							height: '44px',
							marginRight: 16,
						}}
						alt='logo'
						src='https://gw.alipayobjects.com/zos/rmsportal/KDpgvguMpGfqaHPjicRK.svg'
					/>
					机构管理平台
				</h1>
				<div
					style={{
						marginTop: 12,
						textAlign: 'center',
						marginBottom: 40,
					}}>
					充电桩机构管理平台
				</div>
				<ProFormText
					fieldProps={{
						size: 'large',
						prefix: <MobileOutlined />,
					}}
					name='user'
					placeholder='请输入用户名'
					initialValue='admin'
					rules={[
						{
							required: true,
							message: '请输入手机号!',
						},
						// {
						// 	pattern: /^1\d{10}$/,
						// 	message: '不合法的手机号格式!',
						// },
					]}
				/>
				<ProFormText
					fieldProps={{
						type: 'password',
						size: 'large',
						prefix: <LockOutlined />,
					}}
					name='password'
					initialValue='123456'
					placeholder='请输入密码'
					rules={[
						{
							required: true,
							message: '请输入密码!',
						},
					]}
				/>
				<ProFormText
					fieldProps={{
						size: 'large',
						prefix: <KeyOutlined />,
					}}
					name='key'
					placeholder='请输入key'
					initialValue='G0/k+9jl4eTpzsuzS+d8Pg'
					rules={[
						{
							required: true,
							message: '请输入密码!',
						},
					]}
				/>
			</ProForm>
		</div>
	);
};
export default Login;
