import React, { useRef } from 'react';
import { PlusOutlined } from '@ant-design/icons';
import { Button, Tag, Space, Menu, Dropdown } from 'antd';
import type { ProColumns, ActionType } from '@ant-design/pro-table';
import ProForm, {
	ModalForm,
	ProFormText,
	ProFormDateRangePicker,
	ProFormSelect,
} from '@ant-design/pro-form';

import ProTable, { TableDropdown } from '@ant-design/pro-table';

type GithubIssueItem = {
	url: string;
	id: number;
	number: number;
	title: string;
	labels: {
		name: string;
		color: string;
	}[];
	state: string;
	comments: number;
	created_at: string;
	updated_at: string;
	closed_at?: string;
};

const columns: ProColumns<GithubIssueItem>[] = [
	{
		title: '角色id',
		dataIndex: 'id',
		width: 64,
		hideInSearch: true,
	},
	{
		title: '角色名称',
		dataIndex: 'title',
		hideInSearch: false,
		formItemProps: {
			label: '用户',
		},
	},
	{
		title: '操作',
		dataIndex: 'title',
		key: 'option',
		hideInSearch: true,
		render: () => (
			<Space>
				<Button type='link'>编辑</Button>
				<Button type='link'>删除</Button>
			</Space>
		),
	},
];
const modalFormRender = () => {
	return (
		<ModalForm<{
			name: string;
			company: string;
		}>
			title='新建设备'
			trigger={
				<Button type='primary'>
					<PlusOutlined />
					新建
				</Button>
			}
			modalProps={{
				onCancel: () => console.log('run'),
			}}>
			<ProFormText label='角色名称' required placeholder='请输入角色名称' />

			<ProForm.Group label='业务分配'>
				<ProFormText
					width='md'
					required
					name='contract'
					label='所属区域'
					placeholder='请选择所属区域'
				/>
				<ProFormText
					name='contractTime'
					required
					label='员工'
					placeholder='请选择员工'
				/>
			</ProForm.Group>
		</ModalForm>
	);
};
/**
 * @description 角色管理页面
 * @returns
 */
const characterPage: React.FC = () => {
	const actionRef = useRef<ActionType>();
	return (
		<ProTable
			options={{ setting: false, density: false }}
			columns={columns}
			toolBarRender={() => [modalFormRender()]}
		/>
	);
};

export default characterPage;
